@@ -42,53 +42,53 @@ def get_predictions(testTFdataset, model, output_filename):
 	
 ## functions for ensembling using Models
 def ensemble_model_average(models_list, testTFdataset, classification_type):
-    import numpy as np
+	import numpy as np
 
-    test_images_ds = testTFdataset.map(lambda image, idnum : image)
-    NUM_IMAGES = 0
-    for data in test_images_ds.unbatch():
-        NUM_IMAGES += 1
-    if classification_type == 'multiclass':
-        probs = np.average([models_list[i].predict(test_images_ds) for i in range(len(models_list))], axis = 0)
-        preds = np.argmax(probs, axis = -1)
-    elif classification_type == 'binary':
-        
-        preds = np.average([models_list[i].predict(test_images_ds) for i in range(len(models_list))], axis = 0)
-        preds = np.array([1 if i >= 0.5 else 0 for i in preds])
-        preds = np.reshape(preds, newshape = (NUM_IMAGES,) )
-    else:
-        print("Choose classification type between 'multiclass' & 'binary'...Not a valid Input.. Exiting")
-        return
-    return preds
+	test_images_ds = testTFdataset.map(lambda image, idnum : image)
+	NUM_IMAGES = 0
+	for data in test_images_ds.unbatch():
+		NUM_IMAGES += 1
+	if classification_type == 'multiclass':
+		probs = np.average([models_list[i].predict(test_images_ds) for i in range(len(models_list))], axis = 0)
+		preds = np.argmax(probs, axis = -1)
+	elif classification_type == 'binary':
+		
+		preds = np.average([models_list[i].predict(test_images_ds) for i in range(len(models_list))], axis = 0)
+		preds = np.array([1 if i >= 0.5 else 0 for i in preds])
+		preds = np.reshape(preds, newshape = (NUM_IMAGES,) )
+	else:
+		print("Choose classification type between 'multiclass' & 'binary'...Not a valid Input.. Exiting")
+		return
+	return preds
 
 def ensemble_model_weighted(weights, models_list, testTFdataset, classification_type):
-    import numpy as np
-    probs = []
-    test_images_ds = testTFdataset.map(lambda image, idnum : image)
-    NUM_IMAGES = 0
-    for data in test_images_ds.unbatch():
-        NUM_IMAGES += 1
-    
-    if classification_type == 'binary':
-        preds = np.array(sum([models_list[i].predict(test_images_ds) * weights[i] for i in range(len(models_list))]))    
-        preds = np.array([1 if i >= 0.5 else 0 for i in preds])
-        preds = np.reshape(preds, newshape = (NUM_IMAGES,))
-        return preds
-    elif classification_type == 'multiclass':
-        
-        for model in models_list:
-            probs.append(model.predict(test_images_ds))
+	import numpy as np
+	probs = []
+	test_images_ds = testTFdataset.map(lambda image, idnum : image)
+	NUM_IMAGES = 0
+	for data in test_images_ds.unbatch():
+		NUM_IMAGES += 1
+	
+	if classification_type == 'binary':
+		preds = np.array(sum([models_list[i].predict(test_images_ds) * weights[i] for i in range(len(models_list))]))    
+		preds = np.array([1 if i >= 0.5 else 0 for i in preds])
+		preds = np.reshape(preds, newshape = (NUM_IMAGES,))
+		return preds
+	elif classification_type == 'multiclass':
+		
+		for model in models_list:
+			probs.append(model.predict(test_images_ds))
 
-        final_probs = None
-        for i, w in enumerate(weights):
-            final_probs = w * probs[i]
+		final_probs = None
+		for i, w in enumerate(weights):
+			final_probs = w * probs[i]
 
-        preds = np.argmax(final_probs, axis = -1)
-    
-    else:
-        print("Classification type not between 'binary' and 'multiclass'. Please choose the correct classification type...Exiting..")
-        return
-    return preds
+		preds = np.argmax(final_probs, axis = -1)
+	
+	else:
+		print("Classification type not between 'binary' and 'multiclass'. Please choose the correct classification type...Exiting..")
+		return
+	return preds
 
 
 def ensemble_predictions(models_list,  testTFdataset, ensemble_type = 'Model Averaging', classification_type = 'mutliclass', weights = None):
@@ -144,14 +144,10 @@ def test_time_augmentations():
 	print("Feature Coming Soon!")
 
 
-if __name__ == '__main__':
-	pass
-else:
+if __name__ != '__main__':
 	import os
 	#os.system('pip install tensorflow==2.2.0')
 	import tensorflow as tf 
 	import numpy as np
-	if tf.__version__ == '2.4.0':
-		pass
-	else:
+	if tf.__version__ != '2.4.0':
 		print("Tensorflow version mismatch. Either pip install tf version as specified in the docs or import the libraries in the beginning.")
